[Commits] [SCM] claws branch, gtk3, updated. 4.0.0-80-g21b9c03ef

paul at claws-mail.org paul at claws-mail.org
Wed Aug 25 08:25:16 UTC 2021


The branch, gtk3 has been updated
       via  21b9c03ef6b14f404aceba48eda526ffe187c876 (commit)
      from  947a066e563599cc7046128dd2b392ee78c36d57 (commit)

Summary of changes:
 src/password.h     | 32 ++++++++++++++++----------------
 src/password_gtk.h |  2 +-
 2 files changed, 17 insertions(+), 17 deletions(-)


- Log -----------------------------------------------------------------
commit 21b9c03ef6b14f404aceba48eda526ffe187c876
Author: paul <paul at claws-mail.org>
Date:   Wed Aug 25 09:25:12 2021 +0100

    complete s/master/primary/

diff --git a/src/password_gtk.h b/src/password_gtk.h
index b8a19fbbe..cf33a1d76 100644
--- a/src/password_gtk.h
+++ b/src/password_gtk.h
@@ -25,7 +25,7 @@
 #endif
 
 #ifndef PASSWORD_CRYPTO_OLD
-void master_passphrase_change_dialog();
+void primary_passphrase_change_dialog();
 #endif
 
 #endif /* __PASSWORD_GTK_H */

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/src/password.h b/src/password.h
index 4480a5eb6..6755fc2da 100644
--- a/src/password.h
+++ b/src/password.h
@@ -27,27 +27,27 @@
 #include <glib.h>
 
 #ifndef PASSWORD_CRYPTO_OLD
 /* Returns a pointer to master passphrase, asking the user
  * if necessary. Do not free the return value. */
-const gchar *master_passphrase();
+const gchar *primary_passphrase();
 
-/* Returns TRUE if there is a master passphrase set in preferences. */
-gboolean master_passphrase_is_set();
-/* Returns TRUE if input contains correct master passphrase, as set
+/* Returns TRUE if there is a primary passphrase set in preferences. */
+gboolean primary_passphrase_is_set();
+/* Returns TRUE if input contains correct primary passphrase, as set
  * in preferences. */
-gboolean master_passphrase_is_correct(const gchar *input);
-/* Returns TRUE if master passphrase is entered (unlocked). */
-gboolean master_passphrase_is_entered();
-/* Removes (locks) master passphrase, if it was entered previously
+gboolean primary_passphrase_is_correct(const gchar *input);
+/* Returns TRUE if primary passphrase is entered (unlocked). */
+gboolean primary_passphrase_is_entered();
+/* Removes (locks) primary passphrase, if it was entered previously
  * in current session. */
-void master_passphrase_forget();
+void primary_passphrase_forget();
 
-/* Changes master passphrase. Also triggers reencryption of all stored
- * passwords using the new master passphrase.
- * oldp - old master passphrase; if NULL, it will be retrieved using
- *        master_passphrase()
- * newp - new master passphrase */
-void master_passphrase_change(const gchar *oldp, const gchar *newp);
+/* Changes primary passphrase. Also triggers reencryption of all stored
+ * passwords using the new primary passphrase.
+ * oldp - old primary passphrase; if NULL, it will be retrieved using
+ *        primary_passphrase()
+ * newp - new primary passphrase */
+void primary_passphrase_change(const gchar *oldp, const gchar *newp);
 #endif
 
 /* Wrapper around the old, DES-CBC-broken implementation which
@@ -27,27 +27,27 @@
 
 #ifndef PASSWORD_CRYPTO_OLD
-/* Returns a pointer to master passphrase, asking the user
+/* Returns a pointer to primary passphrase, asking the user
  * if necessary. Do not free the return value. */
-- 
Claws Mail


More information about the Commits mailing list